Crate array_parameterized_test

Crate array_parameterized_test 

Macros

generate_tests
A macro used to generate multiple test functions given a parameterized test function name, a const array identifier and the array’s values.

Attribute Macros

parameterized_test
Use as an attribute to annotate a parameterized test function that accepts a single parameter. The attribute must be given the name of a const array that is annotated with the test_parameter attribute. That const array will be used to supply parameter values to the test function.
test_parameter
Use as an attribute to annotate a const array that will be used to supply the input values for a parameterized test.