parameterized_test

Attribute Macro parameterized_test 

#[parameterized_test]
Use as an attribute to annotate a parameterized test function that accepts a single parameter. The attribute must be given the name of a const array that is annotated with the test_parameter attribute. That const array will be used to supply parameter values to the test function.