test_parameter

Attribute Macro test_parameter 

#[test_parameter]
Use as an attribute to annotate a const array that will be used to supply the input values for a parameterized test.

Panics

Panics if the annotated item is not a const array expression. Will also panic if the array contains a path expression that is somehow empty.