generate_tests!() { /* proc-macro */ }Expand description
A macro used to generate multiple test functions given a parameterized test function name, a const array identifier and the array’s values.
generate_tests!() { /* proc-macro */ }A macro used to generate multiple test functions given a parameterized test function name, a const array identifier and the array’s values.